@@ -28,7 +28,7 @@ OPTS = [
                default='libvirt',
                help='Inspector to use for inspecting the hypervisor layer. '
                     'Known inspectors are libvirt, hyperv, vsphere '
-                    'and xenapi.'),
+                    'and xenapi. Note that xenapi has been deprecated.'),
 ]
 
 
@@ -82,7 +82,8 @@ InterfaceStats = collections.namedtuple('InterfaceStats',
                                          'rx_bytes', 'tx_bytes',
                                          'rx_packets', 'tx_packets',
                                          'rx_drop', 'tx_drop',
-                                         'rx_errors', 'tx_errors'])
+                                         'rx_errors', 'tx_errors',
+                                         'rx_bytes_delta', 'tx_bytes_delta'])
 
 
 # Named tuple representing vNIC rate statistics.
@@ -112,7 +113,8 @@ DiskStats = collections.namedtuple('DiskStats',
                                    ['device',
                                     'read_bytes', 'read_requests',
                                     'write_bytes', 'write_requests',
-                                    'errors'])
+                                    'errors', 'wr_total_times',
+                                    'rd_total_times'])
 
 # Named tuple representing disk rate statistics.
 #
@@ -268,6 +270,9 @@ class Inspector(object):
 
 
 def get_hypervisor_inspector(conf):
+    if conf.hypervisor_inspector == 'xenapi':
+        LOG.warning('Support for XenServer/Xen Cloud Platform has been '
+                    'deprecated and will be removed in a future release')
     try:
         namespace = 'ceilometer.compute.virt'
         mgr = driver.DriverManager(namespace,
