@@ -19,13 +19,12 @@ import pkg_resources
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import netutils
-import six
 
-from ceilometer.agent import plugin_base
 from ceilometer import declarative
 from ceilometer.hardware import inspector as insloader
 from ceilometer.hardware.pollsters import util
 from ceilometer.i18n import _
+from ceilometer.polling import plugin_base
 from ceilometer import sample
 
 OPTS = [
@@ -44,7 +43,7 @@ class MeterDefinition(object):
     def __init__(self, definition_cfg):
         self.cfg = definition_cfg
         for fname, fval in self.cfg.items():
-            if (isinstance(fname, six.string_types) and
+            if (isinstance(fname, str) and
                 (fname in self.required_fields or
                  fname.endswith('_inspector'))):
                 setattr(self, fname, fval)
