@@ -18,9 +18,9 @@
 from keystoneauth1 import exceptions
 from oslo_config import cfg
 from oslo_log import log
-import six.moves.urllib.parse as urlparse
 from swiftclient import client as swift
 from swiftclient.exceptions import ClientException
+from urllib import parse as urlparse
 
 from ceilometer import keystone_client
 from ceilometer.polling import plugin_base
@@ -86,14 +86,10 @@ class _Base(plugin_base.PollsterBase):
         swift_api_method = getattr(swift, '%s_account' % self.METHOD)
         for t in tenants:
             try:
-                http_conn = swift.http_connection(
+                yield (t.id, swift_api_method(
                     self._neaten_url(endpoint, t.id,
                                      self.conf.reseller_prefix),
-                    cacert=self.conf.service_credentials.cafile)
-                yield (t.id, swift_api_method(
-                    None,
-                    keystone_client.get_auth_token(ksclient),
-                    http_conn))
+                    keystone_client.get_auth_token(ksclient)))
             except ClientException as e:
                 if e.http_status == 404:
                     LOG.warning("Swift tenant id %s not found.", t.id)
